#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://search.cpan.org/~kwilliams/Module-Build-0.2808/lib/Module/Build.pm
# source           : http://search.cpan.org/CPAN/authors/id/K/KW/KWILLIAMS/Module-Build-0.2808.tar.gz

# Source package name
NAME="Module-Build"
# Zenwalk package name
ZENNAME="perl_Module_Build"
# Package version
VERSION="0.2808"
# Source code URL
SOURCE="http://search.cpan.org/CPAN/authors/id/K/KW/KWILLIAMS/Module-Build-$VERSION.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="Changes INSTALL MANIFEST README"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="noarch"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$ZENNAME: perl-Module-Build - Build and install Perl modules
$ZENNAME:
$ZENNAME: Module::Build is a system for building, testing,
$ZENNAME: and installing Perl modules. It is meant to be
$ZENNAME: an alternative to ExtUtils::MakeMaker
$ZENNAME:
$ZENNAME:
$ZENNAME:
$ZENNAME:
$ZENNAME:
$ZENNAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

# make
cd $NAME-$VERSION
perl Makefile.PL
make

# Install on temporary directory
make install DESTDIR=$PKG

# Copy Docs
mkdir -p $PKG/usr/doc/$ZENNAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$ZENNAME-$VERSION

# Move manpages to the right place
mv $PKG/usr/share/man $PKG/usr
rmdir $PKG/usr/share

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$ZENNAME-$VERSION
cp "$CWD/build-$ZENNAME.sh" "$PKG/usr/src/$ZENNAME-$VERSION/build-$ZENNAME.sh"
chmod a+x "$PKG/usr/src/$ZENNAME-$VERSION/build-$ZENNAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$ZENNAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $ZENNAME-$VERSION-$ARCH-$BUILD.tgz > $ZENNAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
